@@ -11,11 +11,12 @@ def _complete_address(address):
     return address
 class CLI:
     '''
-    fetch code templates on github or gitee
+    fetch code templates from github or gitee.
 
     demo of codetmpl:
         codetmpl list;
         codetmpl export python_package ./
+        codetmpl export gitee.com/peiiii/gitspace:tmpl/python_package ./
     '''
     def hi(cls):
         print('Hi, I am codetmpl.'.center(50, '*'))
